# NEOGRAPHVIZ 

A draw function for neo4j graphs, usable as app or in jupyter notebooks.

Derived and forked from [Nicole White's work](https://github.com/nicolewhite/neo4j-jupyter).

## What can it do?
- display graph DB data
- allow you to run cypher queries from your jupyter notebook
- enable deployment of apps with custom graph queries to make the DB accessible to more people.
- save the graph as html page that can be shared and interacted with.

## Further development
- customisation with jsons
- modifying data in the DB with add and remove queries
- basic automated queries
- better examples and docs:
 - deployment as app to docker
 - in jupyter notebooks